# Отслеживание изменений API Mediascout

## API Mediascout

https://lk.mediascout.ru/swagger/index.html

## Генератор моделей Pydantic

https://docs.pydantic.dev/datamodel_code_generator/

## Зачем?

## Как

    cd $PROJECT_ROOT
    docker run -v (pwd)/src/ord_mediascout_client/:/tmp/gen koxudaxi/datamodel-code-generator \
        --url https://demo.mediascout.ru/swagger/v1/swagger.json --output /tmp/gen/models_autogenerated.py

    git diff src/ord_mediascout_client/models_autogenerated.py


## Как следить, что поменялось
Сначала сгенерируем модели для текущей версии API

```bash
docker run -v (pwd)/src/ord_mediascout_client/:/tmp/gen koxudaxi/datamodel-code-generator \
    --url https://demo.mediascout.ru/swagger/v1/swagger.json --output /tmp/gen/models_autogenerated2.py
```

Старая версия у нас хранится в `models_autogenerated.py`, новая в `models_autogenerated2.py`.
Сравним их:

```bash
pipenv shell
ipython
```

Запускаем команду:

```python
import enum
import pydantic
from src.ord_mediascout_client import models_autogenerated as models
from src.ord_mediascout_client import models_autogenerated2 as agmodels

classes = set()

for m in models.__dict__.values():
    if type(m) in (enum.EnumType, pydantic.main.ModelMetaclass):
        classes.add(m.__name__)

for m in agmodels.__dict__.values():
    if type(m) in (enum.EnumType, pydantic.main.ModelMetaclass):
        classes.add(m.__name__)

def get_diffs(m, agm):
    diffs = {}
    keys = set(m.__dict__.get('__fields__', [])) | set(agm.__dict__.get('__fields__', []))
    for k in keys:
        v = m.__dict__['__fields__'].get(k)
        agv = agm.__dict__['__fields__'].get(k)
        if v is None or agv is None or v._type_display() != agv._type_display() or v.required != agv.required or v.default != agv.default:
            diffs[k] = v, agv

    return diffs

only_in_old_models = set()
only_in_new_models = set()
same_models = set()
diff_models = {}
for c in classes:
    m = getattr(models, c, None)
    agm = getattr(agmodels, c, None)

    if m and agm:
        diffs = get_diffs(m, agm)
        if diffs:
            diff_models[c] = diffs
        else:
            same_models.add(c)
    elif m:
        only_in_old_models.add(c)
    else:
        only_in_new_models.add(c)



if same_models:
    print('SAME --------------')
    for c in sorted(same_models):
        print(c)
    print('-------------------')

if only_in_old_models:
    print('ONLY OLD ----------')
    for c in sorted(only_in_old_models):
        print(c)
    print('-------------------')

if only_in_new_models:
    print('ONLY NEW ----------')
    for c in sorted(only_in_new_models):
        print(c)
    print('-------------------')

if diff_models:
    print('DIFFS -------------')
    for c, diffs in sorted(diff_models.items()):
        print(c)
        for k, v in diffs.items():
            print(' - ', k)
            print('      -', v[0])
            print('      +', v[1])
    print('-------------------')
```
